@@ -89,11 +89,11 @@ class facile_trigger_helper:
 
                 if where == "mobile":
                     device = projects["projects"][k]["device"]
-                    print(color("Test will run against " + device, fg='yellow'))
                 else:
-                    device = ""  
+                    device = ""
 
                 if str(project_id) in string_project.upper():
+                    print(color("Test will run against " + device, fg='yellow'))
                     runner.append(Runner(path, where, device, browser, platform, version))
             return runner
 
@@ -114,16 +114,20 @@ class facile_trigger_helper:
         project_id = args.project_id
         api_gilab_token = args.gitlab_api_token
         target_branch = args.target_branch
+        
         # ref_name = args.ref_name
         print(args.ref_name)
         runnable_list = self.check_project(args.ref_name, args.yaml_file)
 
+        if not runnable_list:
+            print(color("Running default profile", fg='yellow'))
+            runnable_list = self.check_project("default", args.yaml_file)
+
         if runnable_list:
             facile_trigger = pyfiglet.figlet_format("facile.it Trigger Helper", font="larry3d")
             print(color(facile_trigger, fg='yellow'))
-            status = self.trigger_pipeline(runnable_list, git_lab_host, api_gilab_token,
+            self.trigger_pipeline(runnable_list, git_lab_host, api_gilab_token,
                                            target_branch, project_id)
-        return status
 
     def trigger_pipeline(self, runnable_list, git_lab_host, api_gilab_token, target_branch, project_id):
         """
@@ -162,13 +166,14 @@ class facile_trigger_helper:
                 if pipeline.status == "pending":
                     print(color(project.name + " is " + pipeline.status, fg='yellow'))
 
-                elif "Binary crashed" in str(job.trace()) and not retry:
-                    if retry:    
-                        status = False
-                    else:
-                        print(color("Binary crashed, re-trying...", fg='yellow'))
-                        pipeline.retry()
-                        time.sleep(10)
+                #TODO retry running 
+                #elif "Binary crashed" in str(job.trace()) and not retry:
+                #    if retry:    
+                #        status = False
+                #    else:
+                #        print(color("Binary crashed, re-trying...", fg='yellow'))
+                #        pipeline.retry()
+                #        time.sleep(10)
 
                 elif pipeline.status == "running":
                     print(color(project.name + " is " + pipeline.status, fg='blue'))
@@ -179,22 +184,20 @@ class facile_trigger_helper:
                 elif pipeline.status == "failed":
                     print(color(project.name + " is " + pipeline.status, fg='red'))
                     self.flag = False and self.flag
-                    status = False
+
 
                 elif pipeline.status == "canceled":
                     print(color(project.name + " is " + pipeline.status, fg='red'))
                     self.flag = False and self.flag
-                    status = False
+
 
                 elif time.time() > timeout:
                     print(color(project.name + " is " + pipeline.status, fg='red'))
                     self.flag = False and self.flag
-                    status = False
+
 
                 time.sleep(2)
 
-        return status
-
 def run_cli(arguments=None):
     """
 
@@ -204,11 +207,11 @@ def run_cli(arguments=None):
         arguments = sys.argv[1:]
 
     obj_trigger = facile_trigger_helper()
-    status = obj_trigger.main(arguments)
-    if not status:
+    obj_trigger.main(arguments)
+ #   if not status:
+ #       sys.exit(1)
+    if not obj_trigger.flag:
         sys.exit(1)
-    #if not obj_trigger.flag:
-    #    sys.exit(1)
 #    return facile_trigger_helper().main(arguments)
 
 if __name__ == '__main__':
